@@ -46,7 +46,7 @@ Radio::Radio(QWidget *parent) :
 
 
 
-   // radio->start();
+    radio->start();
 
     QTimer *timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(readRds()));
@@ -208,7 +208,11 @@ Radio::~Radio()
         saveCurrentFreq();
         saveCurrentIndex();
 
+	 radio->stop();
 
+    QProcess *myProcess = new QProcess;
+     QString program = "dbus-send --system --type=method_call --dest=org.bluez /org/bluez/1122/hci0 org.bluez.Adapter.SetProperty string:Powered variant:boolean:false";
+    myProcess->execute(program);
 
 
 }
